#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class min_time_step(Real):
    """
    Set Minimum Time Step Size.
    """

    fluent_name = "min-time-step"

    return_type = "<object object at 0x7bdacbe2eb40>"
