#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_10 import option as option_cls
from .value import value as value_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
from .piecewise_polynomial import piecewise_polynomial as piecewise_polynomial_cls
from .polynomial import polynomial as polynomial_cls
from .expression import expression as expression_cls
from .path_length import path_length as path_length_cls
from .gray_band_coefficients import gray_band_coefficients as gray_band_coefficients_cls
from .user_defined_function import user_defined_function as user_defined_function_cls

class absorption_coefficient(Group):
    """
    'absorption_coefficient' child.
    """

    fluent_name = "absorption-coefficient"

    child_names = \
        ['option', 'value', 'piecewise_linear', 'piecewise_polynomial',
         'polynomial', 'expression', 'path_length', 'gray_band_coefficients',
         'user_defined_function']

    _child_classes = dict(
        option=option_cls,
        value=value_cls,
        piecewise_linear=piecewise_linear_cls,
        piecewise_polynomial=piecewise_polynomial_cls,
        polynomial=polynomial_cls,
        expression=expression_cls,
        path_length=path_length_cls,
        gray_band_coefficients=gray_band_coefficients_cls,
        user_defined_function=user_defined_function_cls,
    )

    return_type = "<object object at 0x782eb5ae5520>"
