#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class slit_interior_between_diff_solids(Command):
    """
    Slit interior created between different solids into coupled walls.
    """

    fluent_name = "slit-interior-between-diff-solids"

    return_type = "<object object at 0x782eb51329d0>"
